#
# spec file for package purple-rocketchat
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   rocketchat
Name:           purple-rocketchat
Version:        0.0+git20220925
Release:        3.2
Summary:        RocketChat protocol plugin for libpurple
License:        GPL-2.0-or-later
URL:            https://github.com/EionRobb/purple-rocketchat
Source:         %{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.28.0
BuildRequires:  pkgconfig(json-glib-1.0)
%if 0%{?suse_version} >= 1650
BuildRequires:  pkgconfig(libmarkdown) >= 3.0.0
%else
BuildRequires:  pkgconfig(libmarkdown)
%endif
BuildRequires:  pkgconfig(purple)

%description
RocketChat protocol plugin for libpurple-based applications.

%package -n libpurple-plugin-%{_name}
Summary:        RocketChat protocol plugin for libpurple
Enhances:       libpurple

%description -n libpurple-plugin-%{_name}
RocketChat protocol plugin for libpurple-based applications.

%package -n pidgin-plugin-%{_name}
Summary:        RocketChat protocol plugin for Pidgin
Requires:       libpurple-plugin-%{_name} = %{version}
Supplements:    (libpurple-plugin-%{_name} and pidgin)
BuildArch:      noarch

%description -n pidgin-plugin-%{_name}
RocketChat protocol plugin for libpurple-based applications.

This package provides the icon set for Pidgin.

%prep
%setup -q

%build
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%files -n libpurple-plugin-%{_name}
%license LICENSE
%doc README.md
%{_libdir}/purple-2/lib%{_name}.so

%files -n pidgin-plugin-%{_name}
%dir %{_datadir}/pixmaps/pidgin/
%dir %{_datadir}/pixmaps/pidgin/protocols/
%dir %{_datadir}/pixmaps/pidgin/protocols/*/
%{_datadir}/pixmaps/pidgin/protocols/*/%{_name}.*

%changelog
* Thu Jan 23 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Drop requires_ge pidgin: as pidgin has not been in the buildroot,
  that line silently was a no-op. requires_ge now returns errors in
  those situations. As it as a ho-op so far, we seem to be fine
  without it.
* Wed Mar 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Require pkgconfig(libmarkdown) >= 3.0.0 for oS >= 1650 to avoid
  conflict with libmarkdown2-devel, which also provides the same
  pkgconfig(libmarkdown).
* Tue Nov 15 2022 zero mind <zeromind@gmx.com>
- Update to version 0.0+git20220925 (changes since 0.0+git20210219):
  * compatibility with rocketchat server 4.x
  * fix various memory leaks
  * handle http connection errors when building against Purple 2.x
  * only start the actual login process when api/me could be reached
* Thu Jan 21 2021 Christian Goll <cgoll@suse.com>
- Update to version 0.0+git20210219 (changes since 0.0+git20201219
  * Fix an occasional crash when empty messages are sent by the server
    (boo#1180806) again
* Tue Jan 12 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.0+git20201219 (changes since 0.0+git20200717):
  * Handle data structure change from newer Rocket.Chat servers
    (boo#1180806).
  * Add some additional checks to reduce debug warnings.
* Mon Aug 24 2020 ro@suse.de
- swich to github as source as upstream did
- update to 0.0+git.20200717T223247
* Thu Apr 16 2020 Matej Cepl <mcepl@suse.com>
- Update to version 0.0+hg20200403 (changes since 0.0+hg20190218):
  * 800ef89: Attempt to fetch user statuses at login. Not quite working yet though
  * f723268: Subscribe to status changes to help issue #61
  * 284839c: Use 'hg' instead of 'git' for PLUGIN_VERSION.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 0.0+hg20190218 (changes since 0.0+hg20181203):
  * Add some additional null checks to fix segfault when adding new
    rocketchat server.
  * librocketchat: Avoid NULL pointer assertions.
  * librocketchat: Remove unneded call for group creation.
  * librocketchat: Add default group configuration.
  * Disconnect the account if the SSL cert was invalid.
  * Fix for segfault when trying to remove an invalid username from
    storage.
* Thu Dec  6 2018 sor.alexei@meowr.ru
- Update to version 0.0+hg20181203 (changes since 0.0+hg20180817):
  * Attempt to add support for "Personal Access Token"s.
  * Add support for server path.
  * Prevent server path from being NULL, fix default path.
  * Fix for messages from unknown channels appearing as one-to-one
    IM's.
  * Further tweaks to the unknown channels.
* Sat Aug 18 2018 sor.alexei@meowr.ru
- Update to version 0.0+hg20180817:
  * Allow to override build date with SOURCE_DATE_EPOCH.
* Thu Jul 12 2018 fcrozat@suse.com
- Update to version 0.0+hg20170806:
  * initial support for 2FA.
* Thu Mar 15 2018 sor.alexei@meowr.ru
- Update to version 0.0+hg20170806 (changes since 0.0+hg20170430):
  * Fix homepage.
  * Handle change in the 'getUsersOfRoom' API.
  * Don't explode when we can't create a DM for a non-existent
    user.
- Split Pidgin's pixmaps into the pidgin-plugin-rocketchat package.
* Sun May 28 2017 tbechtold@suse.com
- Initial packaging
